//
//  SimpleOLED - hello_world
//  Created by Stefan Trippler on 2021-02-28.
//
//  This example initializes the display and shows the text "Hello, World!".
//  The OLED SSD1306 must be connected via I2C (aka TwoWire, TWI or simply Wire).
//
//  Connect Pins:
//
//     Arduino    Display
//     -------    -------
//         +5V -> VCC
//         GND -> GND
//         SDA -> SDA
//         SCL -> SCL
//

#include "display_OLED_SSD1306.h"
#include "Wire.h"


#define DISPLAY_I2C_ADDR 0x3C
#define DISPLAY_WIDTH     128
#define DISPLAY_HEIGHT     64

display Display(DISPLAY_I2C_ADDR, DISPLAY_WIDTH, DISPLAY_HEIGHT);


void setup() {
  // put your setup code here, to run once:
  Display.init();
  Wire.setClock(1000000);
}



void loop() {
  show_font("default", false);
  show_font("Topaz", false);
  show_font("Topaz", true);
  show_font("C64", false);
  show_font("C64", true);
}



void show_font(const char *fontName, bool doubleHeight)
{
  char string[32+1];
  int rows=DISPLAY_HEIGHT/8/(doubleHeight?2:1);
  int pages=(256/16)/rows;

  if(Display.setFont(fontName, doubleHeight)!=0)
  {
    Display.clear();
    snprintf(string, 32, "Font \"%s\"\nnot enabled", fontName);
    Display.println(string);
    delay(2000);
    return;
  }
  
  Display.clear();
  snprintf(string, 32, "Font \"%s\",\n%s height:", fontName, doubleHeight?"double":"single");
  Display.println(string);
  delay(2000);
  for(int page=0; page<pages; page++)
  {
    Display.clear();
    for(int row=0; row<rows; row++)
    {
      for(int i=0; i<16; i++)
      {
        string[i] = (char)(unsigned char)(page*rows*16 + row*16 + i);
        if(string[i]==0 || string[i]=='\n')   // special chars: end of line, carriage return
          string[i]=' ';
      }
      string[16]=0;
      Display.println(string);
    }
    delay(2000);
  }

}
